@@ -69,14 +69,12 @@ escape.factor <- function(x, parens = NA, collapse = ", ", con = NULL) {
 
 #' @export
 escape.Date <- function(x, parens = NA, collapse = ", ", con = NULL) {
-  x <- as.character(x)
-  escape.character(x, parens = parens, collapse = collapse, con = con)
+  sql_vector(sql_escape_date(con, x), parens, collapse, con = con)
 }
 
 #' @export
 escape.POSIXt <- function(x, parens = NA, collapse = ", ", con = NULL) {
-  x <- strftime(x, "%Y-%m-%dT%H:%M:%OSZ", tz = "UTC")
-  escape.character(x, parens = parens, collapse = collapse, con = con)
+  sql_vector(sql_escape_datetime(con, x), parens, collapse, con = con)
 }
 
 #' @export
@@ -133,12 +131,26 @@ escape.data.frame <- function(x, parens = TRUE, collapse = ", ", con = NULL) {
     "If you are seeing this error in code that used to work, the most likely ",
     "cause is a change dbplyr 1.4.0. Previously `df$x` or `df[[y]]` implied ",
     "that `df` was a local variable, but  now you must make that explict ",
-    " with `!!` or `local()`, e.g.,  `!!df$x` or `local(df[[\"y\"]))"
+    " with `!!` or `local()`, e.g.,  `!!df$x` or `local(df[[\"y\"]])"
   )
 
   abort(paste(strwrap(message), collapse = "\n"))
 }
 
+#' @export
+escape.reactivevalues <- function(x, parens = TRUE, collapse = ", ", con = NULL) {
+  message <- paste0(
+    "Cannot embed a reactiveValues() object in a SQL query.\n\n",
+    "If you are seeing this error in code that used to work, the most likely ",
+    "cause is a change dbplyr 1.4.0. Previously `df$x` or `df[[y]]` implied ",
+    "that `df` was a local variable, but  now you must make that explict ",
+    " with `!!` or `local()`, e.g.,  `!!df$x` or `local(df[[\"y\"]])"
+  )
+
+  abort(paste(strwrap(message), collapse = "\n"))
+}
+
+
 #' @export
 #' @rdname escape
 sql_vector <- function(x, parens = NA, collapse = " ", con = NULL) {
@@ -215,6 +227,21 @@ sql_escape_logical <- function(con, x) {
   UseMethod("sql_escape_logical")
 }
 
+#' @keywords internal
+#' @export
+#' @rdname sql_escape_logical
+sql_escape_date <- function(con, x) {
+  UseMethod("sql_escape_date")
+}
+
+
+#' @keywords internal
+#' @export
+#' @rdname sql_escape_logical
+sql_escape_datetime <- function(con, x) {
+  UseMethod("sql_escape_datetime")
+}
+
 # DBIConnection methods --------------------------------------------------------
 
 #' @export
@@ -222,6 +249,17 @@ sql_escape_string.DBIConnection <- function(con, x) {
   dbQuoteString(con, x)
 }
 
+#' @export
+sql_escape_date.DBIConnection <- function(con, x) {
+  sql_escape_string(con, as.character(x))
+}
+
+#' @export
+sql_escape_datetime.DBIConnection <- function(con, x) {
+  x <- strftime(x, "%Y-%m-%dT%H:%M:%OSZ", tz = "UTC")
+  sql_escape_string(con, x)
+}
+
 #' @export
 sql_escape_ident.DBIConnection <- function(con, x) {
   dbQuoteIdentifier(con, x)
