@@ -51,7 +51,7 @@ print.op_base_remote <- function(x, ...) {
 
 #' @export
 print.op_base_local <- function(x, ...) {
-  cat("<Local data frame> ", dim_desc(x$x), "\n", sep = "")
+  cat("<Local data frame> ", dplyr::dim_desc(x$x), "\n", sep = "")
 }
 
 #' @export
